<?php

////////////////////////////////////////////////////////////////////
// Settig Theme-options
////////////////////////////////////////////////////////////////////
include_once( trailingslashit( get_template_directory() ) . 'lib/plugin-activation.php' );
include_once( trailingslashit( get_template_directory() ) . 'lib/theme-config.php' );
require_once( trailingslashit( get_template_directory() ) . 'lib/customize-pro/class-customize.php' );

add_action( 'after_setup_theme', 'blogmaster_setup' );

if ( !function_exists( 'blogmaster_setup' ) ) :

	function blogmaster_setup() {

		// Theme lang
		load_theme_textdomain( 'blogmaster', get_template_directory() . '/languages' );

		// Add Title Tag Support
		add_theme_support( 'title-tag' );

		// Register Menus
		register_nav_menus(
		array(
			'main_menu' => __( 'Main Menu', 'blogmaster' ),
		)
		);

		// Add support for a featured image and the size
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 300, 300, true );
		add_image_size( 'blogmaster-home', 731, 441, true );
		add_image_size( 'blogmaster-single', 1170, 450, true );
		add_image_size( 'blogmaster-slider-nav', 234, 131, true );

		// Adds RSS feed links to for posts and comments.
		add_theme_support( 'automatic-feed-links' );
	}

endif;

// Display a admin notices
add_action( 'admin_notices', 'blogmaster_admin_notice' );

function blogmaster_admin_notice() {
	global $current_user;
	$user_id = $current_user->ID;
	/* Check that the user hasn't already clicked to ignore the message */
	if ( !get_user_meta( $user_id, 'blogmaster_ignore_notice' ) ) {
		echo '<div class="updated notice-info point-notice" style="position:relative;"><p>';
		printf( __( 'Like Blogmaster theme? You will <strong>LOVE Blogmaster PRO</strong>! ', 'blogmaster' ) . '<a href="' . esc_url( 'http://themes4wp.com/product/blogmaster-pro/' ) . '" target="_blank">' . __( 'Click here for all the exciting features.', 'blogmaster' ) . '</a><a href="%1$s" class="dashicons dashicons-dismiss dashicons-dismiss-icon" style="position: absolute; top: 8px; right: 8px; color: #222; opacity: 0.4; text-decoration: none !important;"></a>', '?blogmaster_notice_ignore=0' );
		echo "</p></div>";
	}
}

add_action( 'admin_init', 'blogmaster_notice_ignore' );

function blogmaster_notice_ignore() {
	global $current_user;
	$user_id = $current_user->ID;
	/* If user clicks to ignore the notice, add that to their user meta */
	if ( isset( $_GET[ 'blogmaster_notice_ignore' ] ) && '0' == $_GET[ 'blogmaster_notice_ignore' ] ) {
		add_user_meta( $user_id, 'blogmaster_ignore_notice', 'true', true );
	}
}

////////////////////////////////////////////////////////////////////
// Set Content Width
////////////////////////////////////////////////////////////////////

function blogmaster_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'blogmaster_content_width', 800 );
}
add_action( 'after_setup_theme', 'blogmaster_content_width', 0 );

////////////////////////////////////////////////////////////////////
// Enqueue Styles (normal style.css and bootstrap.css)
////////////////////////////////////////////////////////////////////
function blogmaster_theme_stylesheets() {
	wp_enqueue_style( 'blogmaster-bootstra-css', get_template_directory_uri() . '/css/bootstrap.css', array(), '1', 'all' );
	wp_enqueue_style( 'blogmaster-stylesheet', get_stylesheet_uri(), array(), '1', 'all' );
	// load Font Awesome css
	wp_enqueue_style( 'blogmaster-font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css' );
	// load Flexslider css
	wp_enqueue_style( 'blogmaster-flexslider-css', get_template_directory_uri() . '/css/flexslider.css', 'style' );
}

add_action( 'wp_enqueue_scripts', 'blogmaster_theme_stylesheets' );

////////////////////////////////////////////////////////////////////
// Register Bootstrap JS with jquery
////////////////////////////////////////////////////////////////////
function blogmaster_theme_js() {
	wp_enqueue_script( 'blogmaster-bootstrap-js', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ) );
	wp_enqueue_script( 'blogmaster-theme-js', get_template_directory_uri() . '/js/customscript.js', array( 'jquery' ) );
	wp_enqueue_script( 'blogmaster-flexslider-js', get_template_directory_uri() . '/js/jquery.flexslider-min.js', array( 'jquery' ) );
}

add_action( 'wp_enqueue_scripts', 'blogmaster_theme_js' );


////////////////////////////////////////////////////////////////////
// Register Custom Navigation Walker include custom menu widget to use walkerclass
////////////////////////////////////////////////////////////////////

require_once('lib/wp_bootstrap_navwalker.php');

////////////////////////////////////////////////////////////////////
// Theme Info page
////////////////////////////////////////////////////////////////////

if ( is_admin() ) {
	require_once(trailingslashit( get_template_directory() ) . '/lib/theme-info.php');
}

////////////////////////////////////////////////////////////////////
// Register the Sidebar(s)
////////////////////////////////////////////////////////////////////
add_action( 'widgets_init', 'blogmaster_widgets_init' );

function blogmaster_widgets_init() {
	register_sidebar(
	array(
		'name'			 => __( 'Right Sidebar', 'blogmaster' ),
		'id'			 => 'blogmaster-right-sidebar',
		'before_widget'	 => '<div id="%1$s" class="widget %2$s">',
		'after_widget'	 => '</div>',
		'before_title'	 => '<h3 class="widget-title">',
		'after_title'	 => '</h3>',
	) );

	register_sidebar(
	array(
		'name'			 => __( 'Left Sidebar', 'blogmaster' ),
		'id'			 => 'blogmaster-left-sidebar',
		'before_widget'	 => '<div id="%1$s" class="widget %2$s">',
		'after_widget'	 => '</div>',
		'before_title'	 => '<h3 class="widget-title">',
		'after_title'	 => '</h3>',
	) );

	register_sidebar(
	array(
		'name'			 => __( 'Front Page: Content Top Section', 'blogmaster' ),
		'id'			 => 'blogmaster-front-page-content-section',
		'description'	 => __( 'Content Top Section', 'blogmaster' ),
		'before_widget'	 => '<div id="%1$s" class="widget %2$s">',
		'after_widget'	 => '</div>',
		'before_title'	 => '<h3 class="widget-title">',
		'after_title'	 => '</h3>',
	) );

	register_sidebar(
	array(
		'name'			 => __( 'Area After First Post', 'blogmaster' ),
		'id'			 => 'blogmaster-post-area',
		'description'	 => __( 'Suitable for text widget.', 'blogmaster' ),
		'before_widget'	 => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	 => '</aside>',
		'before_title'	 => '<h3 class="widget-title">',
		'after_title'	 => '</h3>',
	) );
}

////////////////////////////////////////////////////////////////////
// Register hook and action to set Main content area col-md- width based on sidebar declarations
////////////////////////////////////////////////////////////////////

add_action( 'blogmaster_main_content_width_hook', 'blogmaster_main_content_width_columns' );

function blogmaster_main_content_width_columns() {

	$columns = '12';

	if ( get_theme_mod( 'rigth-sidebar-check', 1 ) != 0 ) {
		$columns = $columns - absint( get_theme_mod( 'right-sidebar-size', 3 ) );
	}

	if ( get_theme_mod( 'left-sidebar-check', 0 ) != 0 ) {
		$columns = $columns - absint( get_theme_mod( 'left-sidebar-size', 3 ) );
	}

	echo $columns;
}

function blogmaster_main_content_width() {
	do_action( 'blogmaster_main_content_width_hook' );
}

if ( !function_exists( 'blogmaster_breadcrumb' ) ) :
	////////////////////////////////////////////////////////////////////
	// Breadcrumbs
	////////////////////////////////////////////////////////////////////
	function blogmaster_breadcrumb() {
		global $post, $wp_query;
		$home		 = esc_html__( 'Home', 'blogmaster' );
		$delimiter	 = ' &raquo; ';
		$homeLink	 = home_url();
		if ( is_home() || is_front_page() ) {
			// no need for breadcrumbs in homepage
		} else {
			echo '<div id="breadcrumbs" >';
			echo '<div class="breadcrumbs-inner text-right">';
			// main breadcrumbs lead to homepage
			echo '<span><a href="' . esc_url( $homeLink ) . '">' . '<i class="fa fa-home"></i><span>' . esc_attr( $home ) . '</span>' . '</a></span>' . $delimiter . ' ';
			// if blog page exists
			if ( get_page_by_path( 'blog' ) ) {
				if ( !is_page( 'blog' ) ) {
					echo '<span><a href="' . esc_url( get_permalink( get_page_by_path( 'blog' ) ) ) . '">' . '<span>Blog</span></a></span>' . $delimiter . ' ';
				}
			}
			if ( is_category() ) {
				$thisCat = get_category( get_query_var( 'cat' ), false );
				if ( $thisCat->parent != 0 ) {
					$category_link = get_category_link( $thisCat->parent );
					echo '<span><a href="' . $category_link . '">' . '<span>' . get_cat_name( $thisCat->parent ) . '</span>' . '</a></span>' . $delimiter . ' ';
				}
				$category_id	 = get_cat_ID( single_cat_title( '', false ) );
				$category_link	 = get_category_link( $category_id );
				echo '<span><a href="' . $category_link . '">' . '<span>' . single_cat_title( '', false ) . '</span>' . '</a></span>';
			} elseif ( is_single() && !is_attachment() ) {
				if ( get_post_type() != 'post' ) {
					$post_type	 = get_post_type_object( get_post_type() );
					$slug		 = $post_type->rewrite;
					echo '<span><a href="' . esc_url( $homeLink ) . '/' . $slug[ 'slug' ] . '">' . '<span>' . $post_type->labels->singular_name . '</span>' . '</a></span>';
					echo ' ' . $delimiter . ' ' . get_the_title();
				} else {
					$category = get_the_category();
					if ( $category ) {
						foreach ( $category as $cat ) {
							echo '<span><a href="' . get_category_link( $cat->term_id ) . '">' . '<span>' . $cat->name . '</span>' . '</a></span>' . $delimiter . ' ';
						}
					}
					echo get_the_title();
				}
			} elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() && !is_search() ) {
				$post_type = get_post_type_object( get_post_type() );
				echo $post_type->labels->singular_name;
			} elseif ( is_attachment() ) {
				$parent = get_post( $post->post_parent );
				echo '<span><a href="' . get_permalink( $parent ) . '">' . '<span>' . $parent->post_title . '</span>' . '</a></span>';
				echo ' ' . $delimiter . ' ' . get_the_title();
			} elseif ( is_page() && !$post->post_parent ) {
				$get_post_slug	 = $post->post_name;
				$post_slug		 = str_replace( '-', ' ', $get_post_slug );
				echo '<span><a href="' . get_permalink() . '">' . '<span>' . ucfirst( $post_slug ) . '</span>' . '</a></span>';
			} elseif ( is_page() && $post->post_parent ) {
				$parent_id	 = $post->post_parent;
				$breadcrumbs = array();
				while ( $parent_id ) {
					$page			 = get_page( $parent_id );
					$breadcrumbs[]	 = '<span><a href="' . get_permalink( $page->ID ) . '">' . '<span>' . get_the_title( $page->ID ) . '</span>' . '</a></span>';
					$parent_id		 = $page->post_parent;
				}
				$breadcrumbs = array_reverse( $breadcrumbs );
				for ( $i = 0; $i < count( $breadcrumbs ); $i++ ) {
					echo $breadcrumbs[ $i ];
					if ( $i != count( $breadcrumbs ) - 1 )
						echo ' ' . $delimiter . ' ';
				}
				echo $delimiter . '<span><a href="' . get_permalink() . '">' . '<span>' . the_title_attribute( 'echo=0' ) . '</span>' . '</a></span>';
			}
			elseif ( is_tag() ) {
				$tag_id = get_term_by( 'name', single_cat_title( '', false ), 'post_tag' );
				if ( $tag_id ) {
					$tag_link = get_tag_link( $tag_id->term_id );
				}
				echo '<span><a href="' . $tag_link . '">' . '<span>' . single_cat_title( '', false ) . '</span>' . '</a></span>';
			} elseif ( is_author() ) {
				global $author;
				$userdata = get_userdata( $author );
				echo '<span><a href="' . get_author_posts_url( $userdata->ID ) . '">' . '<span>' . $userdata->display_name . '</span>' . '</a></span>';
			} elseif ( is_404() ) {
				echo esc_html__( 'Error 404', 'blogmaster' );
			} elseif ( is_search() ) {
				echo esc_html__( 'Search results for', 'blogmaster' ) . ' ' . get_search_query();
			} elseif ( is_day() ) {
				echo '<span><a href="' . get_year_link( get_the_time( 'Y' ) ) . '">' . '<span>' . get_the_time( 'Y' ) . '</span>' . '</a></span>' . $delimiter . ' ';
				echo '<span><a href="' . get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ) . '">' . '<span>' . get_the_time( 'F' ) . '</span>' . '</a></span>' . $delimiter . ' ';
				echo '<span><a href="' . get_day_link( get_the_time( 'Y' ), get_the_time( 'm' ), get_the_time( 'd' ) ) . '">' . '<span>' . get_the_time( 'd' ) . '</span>' . '</a></span>';
			} elseif ( is_month() ) {
				echo '<span><a href="' . get_year_link( get_the_time( 'Y' ) ) . '">' . '<span>' . get_the_time( 'Y' ) . '</span>' . '</a></span>' . $delimiter . ' ';
				echo '<span><a href="' . get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ) . '">' . '<span>' . get_the_time( 'F' ) . '</span>' . '</a></span>';
			} elseif ( is_year() ) {
				echo '<span><a href="' . get_year_link( get_the_time( 'Y' ) ) . '">' . '<span>' . get_the_time( 'Y' ) . '</span>' . '</a></span>';
			}
			if ( get_query_var( 'paged' ) ) {
				if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() )
					echo ' (';
				echo esc_html__( 'Page', 'blogmaster' ) . ' ' . get_query_var( 'paged' );
				if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() )
					echo ')';
			}
			echo '</div></div>';
		}
	}
	
endif;

////////////////////////////////////////////////////////////////////
// Meta functions
////////////////////////////////////////////////////////////////////
function blogmaster_comments() {
	global $post;
	$args			 = array(
		'number'	 => '1',
		'post_id'	 => $post->ID,
	);
	$comments		 = get_comments( $args );
	$commentslink	 = get_comments_link( $post->ID );
	if ( !empty( $comments ) ) {
		foreach ( $comments as $comment ) :
			$length		 = 80; // adjust to needed length
			$thiscomment = $comment->comment_content;
			if ( strlen( $thiscomment ) > $length ) {
				$thiscomment = substr( $thiscomment, 0, $length );
				$thiscomment = $thiscomment . '...';
			}
			echo '<strong>' . esc_html__( 'By: ', 'blogmaster' ) . '</strong>', ( esc_attr( $comment->comment_author ) . '<br /><p>' . esc_attr( $thiscomment ) . '</p>' );
		endforeach;
	} else {
		echo '<p>' . esc_html__( 'No comments', 'blogmaster' ) . '</p>';
	}
	echo '<p><a href="' . esc_url( $commentslink ) . '" >' . esc_html__( 'Add your comment', 'blogmaster' ) . '</a></p>';
}

function blogmaster_comments_count() {
	global $post;
	$args		 = array(
		'post_id'	 => $post->ID,
		'count'		 => true
	);
	$comments	 = get_comments( $args );
	echo absint( $comments );
}
